@@ -8,10 +8,9 @@
 
 from os import path as osp
 
-import boto3
 import click
 
-from infrahouse_toolkit.cli.lib import get_bucket
+from infrahouse_toolkit.cli.lib import get_bucket, get_s3_client
 
 
 @click.command(name="upload")
@@ -29,7 +28,7 @@ def cmd_upload(ctx, key_name, plan_file):
 
     By default, the S3 url will be s3://<bucket name>/pending/<plan_file>
     """
-    s3_client = boto3.client("s3")
+    s3_client = get_s3_client(role=ctx.obj["aws_assume_role_arn"])
     bucket = ctx.obj["bucket"] or get_bucket(ctx.obj["tf_backend_file"])
     dst_name = key_name or osp.join("pending", plan_file)
     s3_client.upload_file(plan_file, bucket, dst_name)
